@@ -6,7 +6,7 @@ module ActiveModel
   module Validations
     module ClassMethods
       # This method is a shortcut to all default validators and any custom
-      # validator classes ending in 'Validator'. Note that Rails default
+      # validator classes ending in 'Validator'. Note that \Rails default
       # validators can be overridden inside specific classes by creating
       # custom validator classes in their place such as PresenceValidator.
       #
@@ -116,7 +116,7 @@ module ActiveModel
           key = "#{key.to_s.camelize}Validator"
 
           begin
-            validator = key.include?("::") ? key.constantize : const_get(key)
+            validator = const_get(key)
           rescue NameError
             raise ArgumentError, "Unknown validator: '#{key}'"
           end
@@ -130,7 +130,7 @@ module ActiveModel
       # This method is used to define validations that cannot be corrected by end
       # users and are considered exceptional. So each validator defined with bang
       # or <tt>:strict</tt> option set to <tt>true</tt> will always raise
-      # <tt>ActiveModel::StrictValidationFailed</tt> instead of adding error
+      # ActiveModel::StrictValidationFailed instead of adding error
       # when validation fails. See <tt>validates</tt> for more information about
       # the validation itself.
       #
